@@ -15,13 +15,18 @@
  */
 
 #include "tagguesser.h"
-#include "juk_debug.h"
 
-#include <kconfig.h>
-#include <kmacroexpander.h>
-#include <qhash.h>
-#include <kconfiggroup.h>
+#include <algorithm>
+#include <utility>
+
+#include <KConfig>
+#include <KConfigGroup>
 #include <KSharedConfig>
+#include <KMacroExpander>
+
+#include <QHash>
+
+using namespace Qt::Literals::StringLiterals;
 
 FileNameScheme::FileNameScheme(const QString &s)
     : m_regExp(),
@@ -60,69 +65,74 @@ bool FileNameScheme::matches(const QString &fileName) const
      */
     QString stripped = fileName;
     stripped.truncate(stripped.lastIndexOf('.'));
-    return m_regExp.exactMatch(stripped);
+
+    m_regExpMatch = m_regExp.match(stripped);
+    return m_regExpMatch.hasMatch();
 }
 
 QString FileNameScheme::title() const
 {
     if(m_titleField == -1)
         return QString();
-    return m_regExp.capturedTexts().at(m_titleField);
+    return m_regExpMatch.capturedTexts().at(m_titleField);
 }
 
 QString FileNameScheme::artist() const
 {
     if(m_artistField == -1)
         return QString();
-    return m_regExp.capturedTexts().at(m_artistField);
+    return m_regExpMatch.capturedTexts().at(m_artistField);
 }
 
 QString FileNameScheme::album() const
 {
     if(m_albumField == -1)
         return QString();
-    return m_regExp.capturedTexts().at(m_albumField);
+    return m_regExpMatch.capturedTexts().at(m_albumField);
 }
 
 QString FileNameScheme::track() const
 {
     if(m_trackField == -1)
         return QString();
-    return m_regExp.capturedTexts().at(m_trackField);
+    return m_regExpMatch.capturedTexts().at(m_trackField);
 }
 
 QString FileNameScheme::comment() const
 {
     if(m_commentField == -1)
         return QString();
-    return m_regExp.capturedTexts().at(m_commentField);
+    return m_regExpMatch.capturedTexts().at(m_commentField);
 }
 
 QString FileNameScheme::composeRegExp(const QString &s) const
 {
     QHash<QChar, QString> substitutions;
 
-    KConfigGroup config(KSharedConfig::openConfig(), "TagGuesser");
+    KConfigGroup config(KSharedConfig::openConfig(), u"TagGuesser"_s);
 
-    substitutions[ 't' ] = config.readEntry("Title regexp", "([\\w\\s'&_,\\.]+)");
-    substitutions[ 'a' ] = config.readEntry("Artist regexp", "([\\w\\s'&_,\\.]+)");
-    substitutions[ 'A' ] = config.readEntry("Album regexp", "([\\w\\s'&_,\\.]+)");
+    substitutions[ 't' ] = config.readEntry("Title regexp", "([\\w\\s'&_,.]+)");
+    substitutions[ 'a' ] = config.readEntry("Artist regexp", "([\\w\\s'&_,.]+)");
+    substitutions[ 'A' ] = config.readEntry("Album regexp", "([\\w\\s'&_,.]+)");
     substitutions[ 'T' ] = config.readEntry("Track regexp", "(\\d+)");
     substitutions[ 'c' ] = config.readEntry("Comment regexp", "([\\w\\s_]+)");
 
-    QString regExp = QRegExp::escape(s.simplified());
-    regExp = ".*" + regExp;
+    QString regExp = s.simplified()
+        .replace("(", "\\(")
+        .replace(")", "\\)")
+        .replace("[", "\\[")
+        .replace("]", "\\]");
     regExp.replace(' ', "\\s+");
     regExp = KMacroExpander::expandMacros(regExp, substitutions);
-    regExp += "[^/]*$";
-    return regExp;
+    regExp += "[^\\/]*$";
+    return regExp.replace("\\\\", "\\");
 }
 
 QStringList TagGuesser::schemeStrings()
 {
     QStringList schemes;
 
-    KConfigGroup config(KSharedConfig::openConfig(), "TagGuesser");
+    KConfigGroup config(KSharedConfig::openConfig(), u"TagGuesser"_s);
     schemes = config.readEntry("Filename schemes", QStringList());
 
     if ( schemes.isEmpty() ) {
@@ -160,31 +170,23 @@ QStringList TagGuesser::schemeStrings()
 void TagGuesser::setSchemeStrings(const QStringList &schemes)
 {
     KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
-    KConfigGroup group(cfg, "TagGuesser");
+    KConfigGroup group(cfg, u"TagGuesser"_s);
     group.writeEntry("Filename schemes", schemes);
     cfg->sync();
 }
 
 TagGuesser::TagGuesser()
 {
-    loadSchemes();
+    for(const QString &scheme : schemeStrings())
+        m_schemes << FileNameScheme(scheme);
 }
 
 TagGuesser::TagGuesser(const QString &absFileName)
+  : TagGuesser()
 {
-    loadSchemes();
     guess(absFileName);
 }
 
-void TagGuesser::loadSchemes()
-{
-    const QStringList schemes = schemeStrings();
-    QStringList::ConstIterator it = schemes.begin();
-    QStringList::ConstIterator end = schemes.end();
-    for ( ; it != end; ++it )
-        m_schemes += FileNameScheme( *it );
-}
-
 void TagGuesser::guess(const QString &absFileName)
 {
     m_title.clear();
@@ -193,19 +195,18 @@ void TagGuesser::guess(const QString &absFileName)
     m_track.clear();
     m_comment.clear();
 
-    FileNameScheme::List::ConstIterator it = m_schemes.constBegin();
-    FileNameScheme::List::ConstIterator end = m_schemes.constEnd();
-    for (; it != end; ++it) {
-        const FileNameScheme schema(*it);
-        if(schema.matches(absFileName)) {
-            m_title = capitalizeWords(schema.title().replace('_', " ")).trimmed();
-            m_artist = capitalizeWords(schema.artist().replace('_', " ")).trimmed();
-            m_album = capitalizeWords(schema.album().replace('_', " ")).trimmed();
-            m_track = schema.track().trimmed();
-            m_comment = schema.comment().replace('_', " ").trimmed();
-            break;
-        }
+    const auto it = std::find_if(m_schemes.cbegin(), m_schemes.cend(),
+            [absFileName](const auto &scheme) { return scheme.matches(absFileName); });
+    if(it == m_schemes.cend()) {
+        return;
     }
+
+    const auto &scheme = *it;
+    m_title = capitalizeWords(scheme.title().replace('_', " ")).trimmed();
+    m_artist = capitalizeWords(scheme.artist().replace('_', " ")).trimmed();
+    m_album = capitalizeWords(scheme.album().replace('_', " ")).trimmed();
+    m_track = scheme.track().trimmed();
+    m_comment = scheme.comment().replace('_', " ").trimmed();
 }
 
 QString TagGuesser::capitalizeWords(const QString &s)
@@ -216,7 +217,7 @@ QString TagGuesser::capitalizeWords(const QString &s)
     QString result = s;
     result[ 0 ] = result[ 0 ].toUpper();
 
-    const QRegExp wordRegExp("\\s\\w");
+    static const QRegularExpression wordRegExp("\\s\\w");
     int i = result.indexOf( wordRegExp );
     while ( i > -1 ) {
         result[ i + 1 ] = result[ i + 1 ].toUpper();
